@@ -5,8 +5,8 @@
 #' @param sigma.in error covariance matrix \eqn{\boldsymbol\Sigma}
 #' @param gamma.in list of VECM short-run parameter matrices \eqn{\boldsymbol\Gamma_j}
 #' @param axx.in long-run relationships between the independent variables \eqn{\mathbf A_{xx}}
-#' @param ayx.uc.in long-run unconditional relationship between dependent and independent variables, \eqn{\mathbf a_{yx}^{(UC)}}.
-#' The second component ayxC, derived from conditioning, is calculated as\eqn{\mathbf a_{yx}^{(C)}= - \boldsymbol\omega'\mathbf A_{xx}}
+#' @param ayx.uc.in long-run unconditional relationship between dependent and independent variables, \eqn{\mathbf a_{yx}}.
+#' The second component ayxC, derived from conditioning, is calculated as \eqn{\mathbf a_{yx}^{(C)}= - \boldsymbol\omega'\mathbf A_{xx}}
 #' @param ayy.in long-run relationship for the dependent variable \eqn{a_{yy}}
 #' @param mu.in VAR intercept vector \eqn{\boldsymbol\mu} (CASE II)
 #' @param eta.in VAR trend vector \eqn{\boldsymbol\eta} (CASE IV)
@@ -14,7 +14,6 @@
 #' @param aone.in VECM trend \eqn{\boldsymbol{\alpha}_{1}} (CASE V)
 #' @param burn.in burn-in number of observations
 #' @param seed.in optional seed number for random error generation.
-#'
 #' @return A list that includes \itemize{
 #'\item \code{dims}: a vector with the dataset dimension
 #'\item \code{case}: the case given as input
@@ -23,17 +22,25 @@
 #'\item \code{ut}: the generated random error matrix.
 #'\item \code{sigma}: the error covariance matrix \eqn{\boldsymbol\Sigma}.
 #'\item \code{omega}: the \eqn{\boldsymbol\omega} vector of parameters generated via conditioning
-#'\item \code{at}: the conditional long-run parameter matrix \eqn{\tilde{\mathbf A}}
-#'\item \code{ayx1}: the unconditional subvector of the ARDL equation \eqn{\mathbf a_{y.x}^{UC}}
-#'\item \code{ayx}: the conditional subvector of the ARDL equation \eqn{a_{y.x}=a_{y.x}^{UC}-\omega'A_{xx}}
+#'\item \code{at}: the conditional long-run parameter matrix \eqn{\widetilde{\mathbf A}}
+#'\item \code{ayy}: the coefficient weighting the EC term, \eqn{a_{yy}}
+#'\item \code{ayx.uc}: the unconditional subvector of the ARDL equation \eqn{\mathbf a_{yx}}
+#'\item \code{ayx2}: the conditioning effect \eqn{\omega'A_{xx}}
+#'\item \code{ayx.c}: the conditional subvector of the ARDL equation \eqn{\widetilde{a}_{y.x}=a_{yx}-\omega'A_{xx}}
 #'\item \code{gammalist}: the list of unconditional \eqn{\boldsymbol\Gamma_j} parameter matrices
-#'\item \code{psilist}: the list of conditional \eqn{\boldsymbol\psi_{y.x,j}} parameter matrices
-#'\item \code{azero}: the unconditional VECM intercept
-#'\item \code{interc.ardl}: the conditional ARDL intercept
-#'\item \code{aone}: the unconditional VECM trend
-#'\item \code{interc.ardl}: the conditional ARDL trend
-#'\item \code{vmu}: the VAR intercept
-#'\item \code{veta}: the VAR trend}
+#'\item \code{psilist}: the list of conditional \eqn{\boldsymbol\gamma_{y.x,j}} parameter matrices
+#'\item \code{vmu}: the VAR intercept \eqn{\boldsymbol\mu}
+#'\item \code{veta}: the VAR trend \eqn{\boldsymbol\eta}
+#'\item \code{azero}: the unconditional VECM intercept \eqn{\boldsymbol\alpha_0}
+#'\item \code{aone}: the unconditional VECM trend \eqn{\boldsymbol\alpha_1}
+#'\item \code{azero.c}: the conditional VECM intercept \eqn{\boldsymbol\alpha_0^c}
+#'\item \code{aone.c}: the conditional VECM trend \eqn{\boldsymbol\alpha_1^c}
+#'\item \code{interc.ardl}: the conditional ARDL intercept \eqn{\alpha_{0.y}} (case > 2)
+#'\item \code{trend.ardl}: the conditional ARDL trend \eqn{\alpha_{1.y}} (case = 5)
+#'\item \code{theta0}: the \eqn{\theta_0} coefficient in the EC term (case = 2)
+#'\item \code{theta1}: the \eqn{\theta_1} coefficient in the EC term (case = 4)
+#'\item \code{interc.ec}: the conditional ARDL intercept derived from the EC tem \eqn{\alpha^{EC}_{0.y}} (case = 2)
+#'\item \code{trend.ec}: the conditional ARDL trend derived from the EC tem \eqn{\alpha^{EC}_{1.y}} (case = 4)}
 #' @examples
 #'#PARAMETERS
 #'
@@ -59,7 +66,7 @@
 #'                          axx.in = matrix(c(0.3, 0.5, 0.4, 0.3), nrow = 2, ncol = 2),
 #'                          ayx.uc.in = c(0.5,0.6),
 #'                          ayy.in = 0.7,
-#'                          mu.in = rep(0.3, 3),
+#'                          mu.in = rep(0, 3),
 #'                          eta.in = rep(0, 3),
 #'                          azero.in = rep(0.4, 3),
 #'                          aone.in = rep(0, 3),
@@ -70,18 +77,27 @@
 sim_vecm_ardl =
   function(nobs,
            case = 1,
-           sigma.in = diag(3),
+           sigma.in,
            gamma.in,
            axx.in,
            ayx.uc.in,
            ayy.in,
-           mu.in,
-           eta.in,
-           azero.in,
-           aone.in,
+           mu.in = NULL,
+           eta.in = NULL,
+           azero.in = NULL,
+           aone.in = NULL,
            burn.in = nobs * 0.5,
            seed.in = NULL){
 
+    if (!all(eigen(sigma.in)$values >= 0) |
+        !isSymmetric.matrix(sigma.in)) {
+      stop("Invalid covariance matrix.")
+    }
+    
+    if (!inherits(gamma.in,"list")) {
+      stop("gamma.in must be a list.")
+    }
+    
     if (case < 1 | case > 5 | case %% 1 != 0) {
       warning("Inadmissible case. Defaulting to case III.")
       case = 3
@@ -91,39 +107,50 @@ sim_vecm_ardl =
       warning("Inadmissible burn-in value. Defaulting to n * 0.5.")
       burn.in = n * 0.5
     }
+    
+    if(is.null(mu.in)){
+      mu.in = rep(0,ncol(sigma.in))
+    }
+    
+    if(is.null(eta.in)){
+      eta.in = rep(0,ncol(sigma.in))
+    }
+    
+    if(is.null(azero.in)){
+      azero.in = rep(0,ncol(sigma.in))
+    }
+    
+    if(is.null(aone.in)){
+      aone.in = rep(0,ncol(sigma.in))
+    }
 
     if (case == 1 &&
-        (any(mu.in != 0) || any(eta.in != 0) || any(azero.in != 0) || any(aone.in != 0))) {
+        (any(mu.in != 0) || any(azero.in != 0) || any(eta.in != 0) || any(aone.in != 0))) {
       stop("CASE I implies no intercept and no trend, please check parameter values")
     }
 
-    if (case == 2 &&
-        (any(eta.in != 0) || any(azero.in != 0) || any(aone.in != 0))) {
+    if (case == 2 && (any(azero.in != 0) || any(eta.in != 0) || any(aone.in != 0))) {
       stop("CASE II implies restricted intercept and no trend, please check parameter values")
     }
 
-    if (case == 3 && (any(eta.in != 0) || any(aone.in != 0))) {
+    if (case == 3 && (any(mu.in != 0) || any(eta.in != 0) || any(aone.in != 0))) {
       stop("CASE III implies unrestricted intercept and no trend, please check parameter values.")
     }
 
-    if (case == 4 && (any(aone.in != 0))) {
+    if (case == 4 && (any(mu.in != 0) || any(aone.in != 0))) {
       stop(
         "CASE IV implies unrestricted intercept and restricted trend, please check parameter values."
       )
     }
-
-    if (!all(eigen(sigma.in)$values >= 0) |
-        !isSymmetric.matrix(sigma.in)) {
-      stop("Invalid covariance matrix.")
-    }
-
-    if (!inherits(gamma.in,"list")) {
-      stop("gamma.in must be a list.")
+    
+    if (case == 5 && (any(mu.in != 0) || any(eta.in != 0))) {
+      stop(
+        "CASE V implies unrestricted intercept and unrestricted trend, please check parameter values."
+      )
     }
 
     cs = ncol(sigma.in)
     rs = nrow(sigma.in)
-
     cg = unlist(lapply(gamma.in, ncol))
     rg = unlist(lapply(gamma.in, nrow))
     dmu = length(mu.in)
@@ -162,7 +189,8 @@ sim_vecm_ardl =
       psi[[j]] = matrix(gammax[[j]][1,], nrow = 1, ncol = d) -
         omegat %*% matrix(gammax[[j]][-1,], nrow = (d - 1), ncol = d)
     }
-
+    
+    ayy = ayy.in
     Axx = axx.in
     ayx1 = ayx.uc.in
     ayx2 = omegat %*% Axx
@@ -189,6 +217,19 @@ sim_vecm_ardl =
     azero.c0[1] = azero[1] - omegat %*% azero[-1]
     aone.c0[1] = aone[1] - omegat %*% aone[-1]
     
+    theta0 = theta1 = 0
+    thetav = rep(0, d - 1)
+    
+    if(case == 2){
+      thetav = -ayx/(ayy + 0.000001)
+      theta0 = mu.in[1] - thetav %*% mu.in[-1] 
+    }
+    
+    if(case == 4){
+      thetav = -ayx/(ayy + 0.000001)
+      theta1 = eta.in[1] - thetav %*% eta.in[-1] 
+    }
+    
     nss = nobs + burn.in + Mlag + 1
 
     ut = matrix(rnorm(n = nss * d), nss, d) %*% chol(sigma)
@@ -318,18 +359,24 @@ sim_vecm_ardl =
         sigma = sigma,
         omega = omegat,
         at = At,
-        ayx1 = ayx1,
-        ayx = ayx,
+        ayy = ayy.in,
+        ayx.uc = ayx1,
+        ayx.2 = ayx2,
+        ayx.c = ayx,
         gammalist = gammax,
         psilist = psi,
-        azero = azero,
-        azero.c = azero.c0,
-        interc.ardl = azero.c,
-        aone = aone,
-        aone.c = aone.c0,
-        trend.ardl = aone.c,
         vmu = vmu,
-        veta = veta
+        veta = veta,
+        azero = azero,
+        aone = aone,
+        azero.c = azero.c0,
+        aone.c = aone.c0,
+        interc.ardl = azero.c * (case > 2),
+        trend.ardl = aone.c * (case > 4),
+        theta0 = theta0 * (case == 2),
+        theta1 = theta1 * (case == 4),
+        interc.ec = ayy * theta0 * (case == 2),
+        trend.ec = ayy * theta1 * (case == 4)
       )
     )
   }
