@@ -32,4 +32,4 @@ I0_6=c(3.69,3.52,3.39,3.35,3.22,3.22,3.13,3.13,3.16,3.1,3.02,2.84,3.01,2.92,2.79
 I1_6=c(6.12,5.71,5.57,5.34,5.24,5.15,5.13,5.13,5.02,4.98,5.06,4.55,5.07,4.82,4.74,4.59,4.51,4.45,4.44,4.39,4.38,4.3,4.44,4,4.34,4.18,4.09,4.02,3.97,3.91,3.88,3.86,3.85,3.81,3.91,3.6,3.6,3.51,3.47,3.42,3.38,3.37,3.34,3.32,3.31,3.29,3.36,3.17,6.16,5.82,5.74,5.52,5.46,5.36,5.26,5.19,5.15,5.1,5.07,4.69,5.18,4.89,4.81,4.7,4.64,4.57,4.56,4.5,4.47,4.41,4.43,4.14,4.37,4.22,4.15,4.09,4.03,4.02,3.98,3.95,3.91,3.9,3.9,3.72,3.62,3.52,3.49,3.46,3.42,3.41,3.41,3.39,3.36,3.37,3.35,3.25,6.25,5.91,5.68,5.61,5.44,5.34,5.33,5.25,5.2,5.24,5.17,4.79,5.12,4.91,4.79,4.74,4.63,4.57,4.58,4.49,4.5,4.5,4.45,4.23,4.34,4.18,4.11,4.08,4.03,3.98,3.98,3.95,3.94,3.94,3.92,3.75,3.56,3.47,3.45,3.45,3.38,3.37,3.38,3.36,3.36,3.34,3.34,3.27),
 I0_7=c(3.62,3.39,3.24,3.19,3.1,3.04,2.96,2.95,2.97,2.92,2.91,2.65,2.94,2.82,2.73,2.64,2.62,2.56,2.52,2.49,2.5,2.49,2.48,2.3,2.48,2.37,2.32,2.27,2.25,2.2,2.18,2.16,2.16,2.15,2.15,2.02,2.01,1.95,1.92,1.89,1.86,1.84,1.82,1.82,1.81,1.81,1.81,1.72,3.62,3.42,3.23,3.19,3.08,3.06,3.05,2.98,2.98,2.93,2.94,2.62,2.96,2.81,2.73,2.67,2.6,2.59,2.57,2.51,2.51,2.5,2.48,2.29,2.47,2.4,2.32,2.26,2.24,2.22,2.19,2.17,2.16,2.15,2.14,2.01,2.02,1.95,1.92,1.88,1.86,1.85,1.83,1.83,1.82,1.8,1.8,1.72,3.7,3.43,3.33,3.2,3.1,3.05,3.01,2.97,2.94,2.95,2.91,2.68,3.02,2.83,2.78,2.66,2.62,2.57,2.55,2.51,2.49,2.5,2.48,2.31,2.54,2.41,2.34,2.29,2.25,2.23,2.19,2.16,2.16,2.15,2.15,2.02,2.06,1.97,1.93,1.9,1.86,1.84,1.84,1.82,1.82,1.82,1.81,1.72),
 I1_7=c(5.83,5.59,5.37,5.22,4.95,4.96,4.93,4.85,4.81,4.78,4.75,4.31,4.96,4.78,4.57,4.49,4.35,4.3,4.27,4.24,4.15,4.19,4.14,3.86,4.22,4.09,3.95,3.89,3.84,3.78,3.77,3.76,3.68,3.71,3.67,3.47,3.53,3.46,3.38,3.32,3.3,3.28,3.25,3.24,3.22,3.21,3.21,3.06,6.12,5.77,5.44,5.36,5.2,5.12,5.03,4.93,4.92,4.86,4.86,4.42,5.06,4.81,4.62,4.54,4.48,4.41,4.33,4.31,4.28,4.26,4.25,3.97,4.3,4.15,4.02,3.96,3.93,3.86,3.84,3.82,3.79,3.76,3.75,3.58,3.55,3.48,3.39,3.38,3.34,3.31,3.31,3.28,3.25,3.26,3.25,3.15,6,5.69,5.45,5.33,5.15,5.13,5.07,5.01,5.04,4.91,4.86,4.54,5.01,4.77,4.64,4.57,4.42,4.38,4.39,4.33,4.28,4.25,4.24,4.04,4.24,4.09,4,3.98,3.86,3.85,3.84,3.81,3.77,3.76,3.74,3.62,3.48,3.4,3.35,3.37,3.3,3.3,3.3,3.27,3.26,3.25,3.22,3.17))
-usethis::use_data(smk_crit, overwrite = TRUE,internal=TRUE)
+use_data(smk_crit, overwrite = TRUE,internal=TRUE)
